@@ -6,12 +6,12 @@
    (TeX-add-to-alist 'LaTeX-provided-package-options
                      '(("fontenc" "T1") ("geometry" "left=2cm" "right=2cm" "bottom=15mm") ("natbib" "authoryear" "round" "longnamesfirst")))
    (add-to-list 'LaTeX-verbatim-environments-local "alltt")
-   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "path")
-   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "url")
-   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "nolinkurl")
-   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperbaseurl")
-   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperimage")
    (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperref")
+   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperimage")
+   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperbaseurl")
+   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "nolinkurl")
+   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "url")
+   (add-to-list 'LaTeX-verbatim-macros-with-braces-local "path")
    (add-to-list 'LaTeX-verbatim-macros-with-delims-local "path")
    (TeX-run-style-hooks
     "latex2e"
@@ -25,13 +25,9 @@
     "natbib"
     "hyperref")
    (LaTeX-add-labels
-    "sec:orgf333d2b"
-    "sec:org8fb81af"
-    "sec:org9ccf567"
-    "sec:orgfebd2ea")
-   (LaTeX-add-environments
-    '("eptblFigure" LaTeX-env-args ["argument"] 0)
-    '("epfigFigure" LaTeX-env-args ["argument"] 0)
-    '("epFigure" LaTeX-env-args ["argument"] 0)))
+    "sec:orgf215fe2"
+    "sec:org80695a1"
+    "sec:orgb3e0ae9"
+    "sec:org00b2a6c"))
  :latex)
 
